@@ -942,7 +942,9 @@ StopBuildBatchOutputTypeDef = TypedDict(
 
 StopBuildOutputTypeDef = TypedDict("StopBuildOutputTypeDef", {"build": "BuildTypeDef"}, total=False)
 
-TestCaseFilterTypeDef = TypedDict("TestCaseFilterTypeDef", {"status": str}, total=False)
+TestCaseFilterTypeDef = TypedDict(
+    "TestCaseFilterTypeDef", {"status": str, "keyword": str}, total=False
+)
 
 UpdateProjectOutputTypeDef = TypedDict(
     "UpdateProjectOutputTypeDef", {"project": "ProjectTypeDef"}, total=False
